@@ -74,6 +74,13 @@ class TestManifest(TestCase):
         book.extra_data['license'] = 'http://rightsstatements.org/vocab/InC/1.0/'
         assert book.license == book.extra_data['license']
 
+    def test_attribution(self):
+        book = Manifest(short_id='bk123')
+        assert book.attribution is None
+
+        book.extra_data['attribution'] = 'Created by a person'
+        assert book.attribution == book.extra_data['attribution']
+
     def test_rights_statement_id(self):
         book = Manifest(short_id='bk123')
         assert book.rights_statement_id is None
@@ -198,6 +205,15 @@ class TestCanvas(TestCase):
         assert isinstance(page.plain_text_url, str)
         # plain text url returned
         assert page.plain_text_url == 'http://some.org/with/text'
+        # dimensions not in extra data
+        assert page.height is None
+        assert page.width is None
+
+        # with dimensions in extra data
+        extra_data['width'] = 400
+        extra_data['height'] = 300
+        assert page.width == 400
+        assert page.height == 300
 
         # no plain text url, returns None
         page.extra_data['rendering']['format'] = 'some/other-mime'
@@ -351,6 +367,12 @@ class TestIIIFPresentation(TestCase):
                 IIIFPresentation.from_url(manifest_url)
             assert 'Error parsing JSON' in str(excinfo.value)
 
+    def test_from_url_bad_domain(self):
+        manifest_url = 'http://ma.ni/fe.st'
+        with pytest.raises(IIIFException):
+            IIIFPresentation.from_url(manifest_url)
+
+
     def test_from_url_or_file(self):
         with patch.object(IIIFPresentation, 'from_url') as mock_from_url:
             # local fixture file
@@ -466,9 +488,10 @@ class TestManifestImporter(TestCase):
         assert manif.extra_data[pres.seeAlso.id] == mock_extra_data
         assert mock_getiiifurl.called_with(pres.seeAlso.id)
         assert mock_getiiifurl.return_value.json.called_with()
-        # license & logo available
+        # license, logo, & attribution available
         assert manif.license == "http://rightsstatements.org/vocab/NKC/1.0/"
         assert manif.logo == "https://example.com/logo.png"
+        assert manif.attribution == "Created by a person"
 
         assert len(manif.canvases.all()) == len(pres.sequences[0].canvases)
         assert manif.thumbnail.iiif_image_id == \
@@ -524,7 +547,7 @@ class TestManifestImporter(TestCase):
         manif.delete()
         del pres.seeAlso
         manif = self.importer.import_manifest(pres, self.test_manifest)
-        assert set(manif.extra_data.keys()) == set(['logo', 'license'])
+        assert set(manif.extra_data.keys()) == set(['logo', 'license', 'attribution'])
 
         # unsupported type won't import
         pres.id = 'http://some.other/uri'
